summaryrefslogtreecommitdiff
path: root/src/news_type.h
diff options
context:
space:
mode:
authorrubidium <rubidium@openttd.org>2009-02-09 02:57:15 +0000
committerrubidium <rubidium@openttd.org>2009-02-09 02:57:15 +0000
commitc0a8d09ca72873bbbef14dd317cbd29319e54640 (patch)
tree211b57e3a81eed5791f5b6b9709252af6f7d8503 /src/news_type.h
parent90e2465d7d2c770707feeaebfebbe56bd76383f1 (diff)
downloadopenttd-c0a8d09ca72873bbbef14dd317cbd29319e54640.tar.xz
(svn r15428) -Codechange: consistently use colour instead of having both color and colour.
Diffstat (limited to 'src/news_type.h')
-rw-r--r--src/news_type.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/news_type.h b/src/news_type.h
index 02e6f1e8f..00cdfc207 100644
--- a/src/news_type.h
+++ b/src/news_type.h
@@ -68,14 +68,14 @@ enum NewsMode {
/**
* Various OR-able news-item flags.
* note: NF_INCOLOR is set automatically if needed
*/
enum NewsFlag {
NF_NONE = 0, ///< No flag is set.
NF_VIEWPORT = (1 << 1), ///< Does the news message have a viewport? (ingame picture of happening)
NF_TILE = (1 << 2), ///< When clicked on the news message scroll to a given tile? Tile is in data_a
NF_VEHICLE = (1 << 3), ///< When clicked on the message scroll to the vehicle? VehicleID is in data_a
- NF_INCOLOR = (1 << 5), ///< Show the newsmessage in colour, otherwise it defaults to black & white
+ NF_INCOLOUR = (1 << 5), ///< Show the newsmessage in colour, otherwise it defaults to black & white
NF_TILE2 = (1 << 6), ///< There is a second tile to scroll to; tile is in data_b
};
DECLARE_ENUM_AS_BIT_SET(NewsFlag);
@@ -68,14 +68,14 @@ enum NewsMode {
/**
* Various OR-able news-item flags.
- * note: NF_INCOLOR is set automatically if needed
+ * note: NF_INCOLOUR is set automatically if needed
*/
enum NewsFlag {